@@ -858,8 +858,13 @@ class Askdata(SignUp):
         df_query = pd.DataFrame(data=result[0]["attachment"]["body"][0]["details"]["rows"], columns=result[0]["attachment"]["body"][0]["details"]["columns"])
 
         if (on == None and (left_on == None and right_on == None)):
-            join_conditions = self.__get_join_info(df, df_query)["join_list"][0]
-            return df.merge(df_query, how, '', join_conditions["left_on"], join_conditions["right_on"])
+            join_conditions = self.__get_join_info(df, df_query)
+            left_conditions = []
+            right_conditions = []
+            for condition in join_conditions:
+                left_conditions.append(condition["left_on"])
+                right_conditions.append(condition["right_on"])
+            return df.merge(df_query, how, '', left_conditions, right_conditions)
 
         return df.merge(df_query, how, on, left_on, right_on)
 
@@ -908,7 +913,7 @@ class Askdata(SignUp):
         r.raise_for_status()
 
         try:
-            return r.json()["join_list"][0]
+            return r.json()["join_list"]
         except:
             logging.error(r.json())
 
